@@ -23,9 +23,9 @@
 #define LOGTREE_H
 
 
-#include <qptrlist.h>
+#include <qlist.h>
 
-#include <qtable.h>
+#include <q3table.h>
 
 
 class LogTreeItem;
@@ -37,17 +37,19 @@ struct LogInfo;
 }
 
 
-typedef QPtrList<LogTreeItem> LogTreeItemList;
-typedef QPtrList<LogTreeConnection> LogTreeConnectionList;
+typedef QList<LogTreeItem*> LogTreeItemList;
+typedef QList<LogTreeConnection*> LogTreeConnectionList;
 
 
-class LogTreeView : public QTable
+class LogTreeView : public Q3Table
 {
     Q_OBJECT
 
 public:
     explicit LogTreeView( QWidget *parent=0, const char *name=0 );
 
+    virtual ~LogTreeView();
+
     void addRevision(const Cervisia::LogInfo& logInfo);
     void setSelectedPair(QString selectionA, QString selectionB);
     void collectConnections();
