@@ -29,17 +29,16 @@
 #include <qfileinfo.h>
 #include <qregexp.h>
 #include <qstringlist.h>
-#include <kconfig.h>
 #include <kemailsettings.h>
 #include <klocale.h>
 #include <kmessagebox.h>
-#include <kprocess.h>
-#include <ktempfile.h>
+#include <k3process.h>
+#include <ktemporaryfile.h>
 #include <kuser.h>
 #include <kdebug.h>
 
-#include "cvsservice_stub.h"
-#include "progressdlg.h"
+#include "cvsserviceinterface.h"
+#include "progressdialog.h"
 
 // These regular expression parts aren't useful to check the validity of the
 // CVSROOT specification. They are just used to extract the different parts of it.
@@ -73,16 +72,16 @@ static int FindWhiteSpace(const QString& str, int index)
 
 
 static const QStringList FetchBranchesAndTags(const QString& searchedType,
-                                              CvsService_stub* cvsService,
+                                              OrgKdeCervisiaCvsserviceCvsserviceInterface* cvsService,
                                               QWidget* parent)
 {
     QStringList branchOrTagList;
 
-    DCOPRef job = cvsService->status(QStringList(), true, true);
-    if( !cvsService->ok() )
+    QDBusReply<QDBusObjectPath> job = cvsService->status(QStringList(), true, true);
+    if( !job.isValid() )
         return branchOrTagList;
 
-    ProgressDialog dlg(parent, "Status", job, QString::null, i18n("CVS Status"));
+    ProgressDialog dlg(parent, "Status", cvsService->service(),job, QString(), i18n("CVS Status"));
 
     if( dlg.execute() )
     {
@@ -95,9 +94,9 @@ static const QStringList FetchBranchesAndTags(const QString& searchedType,
                 continue;
             if( (wsPos = FindWhiteSpace(line, 2)) < 0 )
                 continue;
-            if( (bracketPos = line.find('(', wsPos + 1)) < 0 )
+            if( (bracketPos = line.indexOf('(', wsPos + 1)) < 0 )
                 continue;
-            if( (colonPos = line.find(':', bracketPos + 1)) < 0 )
+            if( (colonPos = line.indexOf(':', bracketPos + 1)) < 0 )
                 continue;
 
             const QString tag  = line.mid(1, wsPos - 1);
@@ -117,12 +116,12 @@ bool Cervisia::IsValidTag(const QString& tag)
 {
     static const QString prohibitedChars("$,.:;@");
 
-    if( !isalpha(tag[0].latin1()) )
+    if( !isalpha(tag[0].toLatin1()) )
         return false;
 
-    for( uint i = 1; i < tag.length(); ++i )
+    for( int i = 1; i < tag.length(); ++i )
     {
-        if( !isgraph(tag[i].latin1()) || prohibitedChars.contains(tag[i]) )
+        if( !isgraph(tag[i].toLatin1()) || prohibitedChars.contains(tag[i]) )
                 return false;
     }
 
@@ -142,7 +141,7 @@ QString Cervisia::UserName()
         // 2. Try to retrieve the information from the system
         struct passwd* pw = getpwuid(getuid());
         if( !pw )
-            return QString::null;
+            return QString();
 
         char hostname[512];
         hostname[0] = '\0';
@@ -151,14 +150,14 @@ QString Cervisia::UserName()
             hostname[sizeof(hostname)-1] = '0';
 
         name  = QString::fromLocal8Bit(pw->pw_gecos);
-        email = QString::fromLocal8Bit(pw->pw_name) + "@" +
+        email = QString::fromLocal8Bit(pw->pw_name) + '@' +
                 QString::fromLocal8Bit(hostname);
     }
 
     QString result = name;
     result += "  <";
     result += email;
-    result += ">";
+    result += '>';
 
     return result;
 }
@@ -175,17 +174,17 @@ QString Cervisia::NormalizeRepository(const QString& repository)
 
     // extract username, hostname, port and path from CVSROOT
     QString userName, hostName, port, path;
-    if( rx.search(repository) != -1 )
+    if( repository.contains( rx ) )
     {
         userName = rx.cap(2);
         hostName = rx.cap(4);
         port     = rx.cap(6);
         path     = rx.cap(7);
 
-        kdDebug() << "NormalizeRepository(): username=" << userName << endl;
-        kdDebug() << "NormalizeRepository(): hostname=" << hostName << endl;
-        kdDebug() << "NormalizeRepository(): port    =" << port << endl;
-        kdDebug() << "NormalizeRepository(): path    =" << path << endl;
+        kDebug(8050) << "username=" << userName;
+        kDebug(8050) << "hostname=" << hostName;
+        kDebug(8050) << "port    =" << port;
+        kDebug(8050) << "path    =" << path;
 
         if( port.isEmpty() )
             port = "2401";
@@ -193,11 +192,11 @@ QString Cervisia::NormalizeRepository(const QString& repository)
         if( userName.isEmpty() )
             userName = KUser().loginName();
 
-        QString canonicalForm = ":pserver:" + userName + "@" + hostName +
-                                ":" + port + path;
+        QString canonicalForm = ":pserver:" + userName + '@' + hostName +
+                                ':' + port + path;
 
-        kdDebug() << "NormalizeRepository(): canonicalForm=" << canonicalForm
-                  << endl;
+        kDebug(8050) << "canonicalForm=" << canonicalForm
+                     << endl;
         return canonicalForm;
     }
     else
@@ -215,9 +214,9 @@ bool Cervisia::CheckOverwrite(const QString& fileName, QWidget* parent)
     if( fi.exists() )
     {
         result = (KMessageBox::warningContinueCancel(parent,
-                  i18n("A file named \"%1\" already exists. Are you sure you want to overwrite it?").arg(fileName),
+                  i18n("A file named \"%1\" already exists. Are you sure you want to overwrite it?", fileName),
                   i18n("Overwrite File?"),
-                  KGuiItem(i18n("&Overwrite"), "filesave", i18n("Overwrite the file"))) == KMessageBox::Continue);
+                  KGuiItem(i18n("&Overwrite"), "document-save", i18n("Overwrite the file"))) == KMessageBox::Continue);
     }
 
     return result;
@@ -230,8 +229,8 @@ QString joinLine(const QStringList &list)
     for ( QStringList::ConstIterator it = list.begin();
           it != list.end(); ++it )
     {
-        line += KShellProcess::quote(*it);
-        line += " ";
+        line += K3ShellProcess::quote(*it);
+        line += ' ';
     }
 
     if (line.length() > 0)
@@ -247,8 +246,8 @@ QStringList splitLine(QString line, char delim)
     int pos;
     QStringList list;
 
-    line = line.simplifyWhiteSpace();
-    while ((pos = line.find(delim)) != -1)
+    line = line.simplified();
+    while ((pos = line.indexOf(delim)) != -1)
     {
         list.append(line.left(pos));
         line = line.mid(pos+1, line.length()-pos-1);
@@ -259,16 +258,16 @@ QStringList splitLine(QString line, char delim)
 }
 
 
-const QStringList fetchBranches(CvsService_stub* cvsService, QWidget* parent)
+const QStringList fetchBranches(OrgKdeCervisiaCvsserviceCvsserviceInterface* cvsService, QWidget* parent)
 {
-    return FetchBranchesAndTags(QString::fromLatin1("branch"), cvsService,
+    return FetchBranchesAndTags(QLatin1String("branch"), cvsService,
                                 parent);
 }
 
 
-const QStringList fetchTags(CvsService_stub* cvsService, QWidget* parent)
+const QStringList fetchTags(OrgKdeCervisiaCvsserviceCvsserviceInterface* cvsService, QWidget* parent)
 {
-    return FetchBranchesAndTags(QString::fromLatin1("revision"), cvsService,
+    return FetchBranchesAndTags(QLatin1String("revision"), cvsService,
                                 parent);
 }
 
@@ -292,9 +291,12 @@ QString tempFileName(const QString& suffix)
     if (!tempFiles)
         tempFiles = new QStringList;
 
-    KTempFile f(QString::null, suffix);
-    tempFiles->append(f.name());
-    return f.name();
+    KTemporaryFile f;
+    f.setSuffix(suffix);
+    f.setAutoRemove(false);
+    f.open();
+    tempFiles->append(f.fileName());
+    return f.fileName();
 }
 
 
@@ -309,12 +311,12 @@ int compareRevisions(const QString& rev1, const QString& rev2)
     int startPos2(0);
     while (startPos1 < length1 && startPos2 < length2)
     {
-        int pos1(rev1.find('.', startPos1));
+        int pos1(rev1.indexOf('.', startPos1));
         if (pos1 < 0)
             pos1 = length1;
         const int partLength1(pos1 - startPos1);
 
-        int pos2(rev2.find('.', startPos2));
+        int pos2(rev2.indexOf('.', startPos2));
         if (pos2 < 0)
             pos2 = length2;
         const int partLength2(pos2 - startPos2);
