@@ -12,30 +12,32 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
+#include "costlistitem.h"
+
 #include <math.h>
 
-#include <qpainter.h>
-#include <qregexp.h>
+#include <QPainter>
+#include <QRegExp>
+#include <QPixmap>
 
 #include <klocale.h>
 #include <kiconloader.h>
-#include <kapplication.h>
 
 #include "listutils.h"
-#include "costlistitem.h"
 #include "coverage.h"
 #include "configuration.h"
 
+
 // CostListItem
 
 
-CostListItem::CostListItem(QListView* parent, TraceCostItem* costItem,
-                           TraceCostType* ct, int size)
-  :QListViewItem(parent)
+CostListItem::CostListItem(Q3ListView* parent, TraceCostItem* costItem,
+                           TraceEventType* ct, int size)
+  :Q3ListViewItem(parent)
 {
   _groupSize = size;
   _skipped = 0;
@@ -49,18 +51,18 @@ CostListItem::CostListItem(QListView* parent, TraceCostItem* costItem,
   }
 }
 
-CostListItem::CostListItem(QListView* parent, int skipped,
-			   TraceCostItem* costItem, TraceCostType* ct)
-  :QListViewItem(parent)
+CostListItem::CostListItem(Q3ListView* parent, int skipped,
+			   TraceCostItem* costItem, TraceEventType* ct)
+  :Q3ListViewItem(parent)
 {
   _skipped = skipped;
   _costItem = costItem;
   setCostType(ct);
 
-  setText(1, i18n("(%n item skipped)", "(%n items skipped)", _skipped));
+  setText(1, i18np("(%1 item skipped)", "(%1 items skipped)", _skipped));
 }
 
-void CostListItem::setCostType(TraceCostType* ct)
+void CostListItem::setCostType(TraceEventType* ct)
 {
   _costType = ct;
   update();
@@ -112,7 +114,7 @@ void CostListItem::update()
   setPixmap(0, costPixmap(_costType, _costItem, total, false));
 }
 
-int CostListItem::compare(QListViewItem * i, int col, bool ascending ) const
+int CostListItem::compare(Q3ListViewItem * i, int col, bool ascending ) const
 {
   const CostListItem* fi1 = this;
   const CostListItem* fi2 = (CostListItem*) i;
@@ -132,5 +134,5 @@ int CostListItem::compare(QListViewItem * i, int col, bool ascending ) const
     if (fi1->_pure > fi2->_pure) return 1;
     return 0;
   }
-  return QListViewItem::compare(i, col, ascending);
+  return Q3ListViewItem::compare(i, col, ascending);
 }
