@@ -12,8 +12,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 /*
@@ -23,24 +23,33 @@
 #ifndef FUNCTIONSELECTION_H
 #define FUNCTIONSELECTION_H
 
-#include "functionselectionbase.h"
+#include <QTimer>
+
+#include "ui_functionselectionbase.h"
 #include "traceitemview.h"
 #include "tracedata.h"
 #include "listutils.h"
 
-class QPopupMenu;
 
-class TraceFunction;
-class TraceData;
-class StackBrowser;
-class NestedAreaItem;
+class Q3PopupMenu;
+
+
+
+class FunctionSelectionBase : public QWidget, public Ui::FunctionSelectionBase
+{
+public:
+  FunctionSelectionBase( QWidget *parent ) : QWidget( parent ) {
+    setupUi( this );
+  }
+};
+
 
 class FunctionSelection : public FunctionSelectionBase, public TraceItemView
 {
   Q_OBJECT
 
 public:
-  FunctionSelection( TopLevel*, QWidget* parent = 0, const char* name = 0);
+  explicit FunctionSelection(TopLevel*, QWidget* parent = 0);
   ~FunctionSelection();
 
   TraceCostItem* group(QString);
@@ -50,18 +59,18 @@ public:
 
   QWidget* widget() { return this; }
 
-  void addGroupMenu(QPopupMenu*);
+  void addGroupMenu(Q3PopupMenu*);
 
 public slots:
-  void searchEntered();
+  void searchReturnPressed();
   void searchChanged(const QString&);
   void queryDelayed();
-  void groupDoubleClicked( QListViewItem* );
-  void functionActivated( QListViewItem* );
-  void groupSelected( QListViewItem* );
-  void functionSelected( QListViewItem* );
-  void functionContext(QListViewItem*, const QPoint &, int);
-  void groupContext(QListViewItem*, const QPoint &, int);
+  void groupDoubleClicked( Q3ListViewItem* );
+  void functionActivated( Q3ListViewItem* );
+  void groupSelected( Q3ListViewItem* );
+  void functionSelected( Q3ListViewItem* );
+  void functionContext(Q3ListViewItem*, const QPoint &, int);
+  void groupContext(Q3ListViewItem*, const QPoint &, int);
 
 private:
   TraceItem* canShow(TraceItem* i);
@@ -69,7 +78,7 @@ private:
   void selectFunction();
   void refresh();
   void setCostColumnWidths();
-  void updateGroupSizes();
+  void updateGroupSizes(bool hideEmpty);
 
   TraceCostItem* _group;
 
