@@ -274,6 +274,7 @@ void SourceView::doUpdate(int changeType)
 
 void SourceView::refresh()
 {
+  int originalPosition = verticalScrollBar()->value();
   clear();
   setColumnWidth(0, 20);
   setColumnWidth(1, 50);
@@ -333,6 +334,8 @@ void SourceView::refresh()
     setColumnWidthMode(2, Q3ListView::Manual);
     setColumnWidth(2, 0);
   }
+  // reset to the original position - this is useful when the view is refreshed just because we change between relative/absolute 
+  verticalScrollBar()->setValue(originalPosition);
 }
 
 
@@ -350,7 +353,7 @@ static bool checkFileExistance(QString& dir, const QString& name)
   d.setFilter( QDir::Dirs | QDir::NoSymLinks );
   d.setSorting( QDir::Unsorted );
   QStringList subdirs = d.entryList();
-  QStringList::Iterator it =subdirs.begin();
+  QStringList::const_iterator it =subdirs.begin();
   for(; it != subdirs.end(); ++it ) {
     if (*it == "." || *it == ".." || *it == "CVS") continue;
 
@@ -528,7 +531,7 @@ void SourceView::fillSourceFile(TraceFunctionSource* sf, int fileno)
     if (!QFile::exists(filename)) {
       QStringList list = Configuration::sourceDirs(_data,
 						   sf->function()->object());
-      QStringList::Iterator it;
+      QStringList::const_iterator it;
 
       for ( it = list.begin(); it != list.end(); ++it ) {
         dir = *it;
