@@ -12,27 +12,30 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 /*
  * Items of stack dockable.
  */
 
-#include <qpixmap.h>
+#include "stackitem.h"
+
+#include <QPixmap>
+
 #include <klocale.h>
 
 #include "configuration.h"
 #include "listutils.h"
-#include "stackitem.h"
 #include "stackselection.h"
 
+
 // StackItem
 
 StackItem::StackItem(StackSelection* ss, 
-		     QListView* parent, TraceFunction* f)
-  :QListViewItem(parent)
+		     Q3ListView* parent, TraceFunction* f)
+  :Q3ListViewItem(parent)
 {
   _view = ss;
   _function = f;
@@ -46,8 +49,8 @@ StackItem::StackItem(StackSelection* ss,
 }
 
 StackItem::StackItem(StackSelection* ss,
-		     QListView* parent, TraceCall* call)
-  :QListViewItem(parent)
+		     Q3ListView* parent, TraceCall* call)
+  :Q3ListViewItem(parent)
 {
   _view = ss;
   _call = call;
@@ -73,7 +76,7 @@ void StackItem::updateCost()
 
   setText(2, _call->prettyCallCount());
 
-  TraceCostType* ct = _view->costType();
+  TraceEventType* ct = _view->eventType();
   _sum = _call->subCost(ct);
   double total = _call->called()->data()->subCost(ct);
   if (total == 0.0) {
@@ -92,8 +95,8 @@ void StackItem::updateCost()
     setPixmap(0, costPixmap(ct, _call, total, false));
   }
 
-  // if _costType2 is 0, column1 is hidden, no change needed
-  TraceCostType* ct2 = _view->costType2();
+  // if _eventType2 is 0, column1 is hidden, no change needed
+  TraceEventType* ct2 = _view->eventType2();
   if (!ct2) return;
 
   _sum = _call->subCost(ct2);
