@@ -19,6 +19,7 @@
 
 #include <QtGui/QCheckBox>
 #include <Q3HGroupBox>
+#include <QGroupBox>
 #include <QtGui/QLabel>
 #include <QtGui/QLayout>
 #include <QtGui/QRadioButton>
@@ -212,7 +213,7 @@ void DiffPage::addDiffTab()
 	layout->setMargin( KDialog::marginHint() );
 
 	// add diff program selector
-	m_diffProgramGroup = new KButtonGroup( page );
+	m_diffProgramGroup = new QGroupBox( page );
 	layout->addWidget( m_diffProgramGroup );
 	QVBoxLayout* bgLayout = new QVBoxLayout( m_diffProgramGroup );
 	m_diffProgramGroup->setTitle( i18n( "Diff Program" ) );
@@ -247,14 +248,8 @@ void DiffPage::addFormatTab()
 	QRadioButton* radioButton;
 	radioButton = new QRadioButton( i18n( "Context" ), m_modeButtonGroup );
 	bgLayout->addWidget( radioButton );
-	radioButton = new QRadioButton( i18n( "Ed" ),      m_modeButtonGroup );
-	radioButton->setEnabled( false );
-	bgLayout->addWidget( radioButton );
 	radioButton = new QRadioButton( i18n( "Normal" ),  m_modeButtonGroup );
 	bgLayout->addWidget( radioButton );
-	radioButton = new QRadioButton( i18n( "RCS" ),     m_modeButtonGroup );
-	radioButton->setEnabled( false );
-	bgLayout->addWidget( radioButton );
 	radioButton = new QRadioButton( i18n( "Unified" ), m_modeButtonGroup );
 	bgLayout->addWidget( radioButton );
 
