@@ -1,13 +1,10 @@
 /***************************************************************************
-                                kompareprocess.cpp  -  description
-                                -------------------
+                                kompareprocess.cpp
+                                ------------------
         begin                   : Sun Mar 4 2001
-        copyright               : (C) 2001-2003 by Otto Bruggeman
-                                  and John Firebaugh
-                                  (C) 2007      Kevin Kofler
-        email                   : otto.bruggeman@home.nl
-                                  jfirebaugh@kde.org
-                                  kevin.kofler@chello.at
+        Copyright 2001-2005,2009 Otto Bruggeman <bruggie@gmail.com>
+        Copyright 2001-2003 John Firebaugh <jfirebaugh@kde.org>
+        Copyright 2007-2008 Kevin Kofler   <kevin.kofler@chello.at>
 ****************************************************************************/
 
 /***************************************************************************
@@ -19,16 +16,19 @@
 **
 ***************************************************************************/
 
-#include <qdir.h>
-#include <qstringlist.h>
-#include <qtextcodec.h>
+#include "kompareprocess.h"
+
+#include <QtCore/QDir>
+#include <QtCore/QStringList>
+#include <QtCore/QTextCodec>
+#include <Q3ValueList>
+#include <Q3CString>
 
 #include <kcharsets.h>
 #include <kdebug.h>
 #include <kglobal.h>
 
 #include "diffsettings.h"
-#include "kompareprocess.h"
 
 KompareProcess::KompareProcess( DiffSettings* diffSettings, enum Kompare::DiffMode mode, QString source, QString destination, QString dir )
 	: KProcess(),
@@ -36,19 +36,11 @@ KompareProcess::KompareProcess( DiffSettings* diffSettings, enum Kompare::DiffMo
 	m_mode( mode ),
 	m_textDecoder( 0 )
 {
-	setUseShell( true );
-
-	// connect the stdout and stderr signals
-	connect( this, SIGNAL( receivedStdout( KProcess*, char*, int ) ),
-	         SLOT  ( slotReceivedStdout( KProcess*, char*, int ) ) );
-	connect( this, SIGNAL( receivedStderr( KProcess*, char*, int ) ),
-	         SLOT  ( slotReceivedStderr( KProcess*, char*, int ) ) );
-
 	// connect the signal that indicates that the proces has exited
-	connect( this, SIGNAL( processExited( KProcess* ) ),
-	         SLOT  ( slotProcessExited( KProcess* ) ) );
+	connect( this, SIGNAL( finished( int, QProcess::ExitStatus ) ),
+	         SLOT  ( slotFinished( int, QProcess::ExitStatus ) ) );
 
-	*this << "LANG=C";
+	setEnv( "LANG", "C" );
 
 	// Write command and options
 	if( m_mode == Kompare::Default )
@@ -61,13 +53,13 @@ KompareProcess::KompareProcess( DiffSettings* diffSettings, enum Kompare::DiffMo
 	}
 
 	if( !dir.isEmpty() ) {
-		QDir::setCurrent( dir );
+		setWorkingDirectory( dir );
 	}
 
 	// Write file names
 	*this << "--";
-	*this << KProcess::quote( constructRelativePath( dir, source ) );
-	*this << KProcess::quote( constructRelativePath( dir, destination ) );
+	*this << constructRelativePath( dir, source );
+	*this << constructRelativePath( dir, destination );
 }
 
 void KompareProcess::writeDefaultCommandLine()
@@ -86,15 +78,15 @@ void KompareProcess::writeDefaultCommandLine()
 
 void KompareProcess::writeCommandLine()
 {
-	// load the executable into the KProcess
+	// load the executable into the K3Process
 	if ( m_diffSettings->m_diffProgram.isEmpty() )
 	{
-		kdDebug(8101) << "Using the first diff in the path..." << endl;
+		kDebug(8101) << "Using the first diff in the path..." << endl;
 		*this << "diff";
 	}
 	else
 	{
-		kdDebug(8101) << "Using a user specified diff, namely: " << m_diffSettings->m_diffProgram << endl;
+		kDebug(8101) << "Using a user specified diff, namely: " << m_diffSettings->m_diffProgram << endl;
 		*this << m_diffSettings->m_diffProgram;
 	}
 
@@ -120,7 +112,13 @@ void KompareProcess::writeCommandLine()
 		break;
 	}
 
-	if ( m_diffSettings->m_largeFiles )
+	if ( m_diffSettings->m_largeFiles 
+// default diff does not have -H on OpenBSD
+// so don't pass this option unless the user overrode the default program
+#if defined(__OpenBSD__)
+		&& !m_diffSettings->m_diffProgram.isEmpty() 
+#endif
+	   )
 	{
 		*this << "-H";
 	}
@@ -157,7 +155,7 @@ void KompareProcess::writeCommandLine()
 
 	if ( m_diffSettings->m_ignoreRegExp && !m_diffSettings->m_ignoreRegExpText.isEmpty() )
 	{
-		*this << "-I " << KProcess::quote( m_diffSettings->m_ignoreRegExpText );
+		*this << "-I " << m_diffSettings->m_ignoreRegExpText;
 	}
 
 	if ( m_diffSettings->m_showCFunctionChange )
@@ -192,23 +190,24 @@ void KompareProcess::writeCommandLine()
 		QStringList::ConstIterator end = m_diffSettings->m_excludeFilePatternList.end();
 		for ( ; it != end; ++it )
 		{
-			*this << "-x" << KProcess::quote( *it );
+			*this << "-x" << *it;
 		}
 	}
 
 	if ( m_diffSettings->m_excludeFilesFile && !m_diffSettings->m_excludeFilesFileURL.isEmpty() )
 	{
-		*this << "-X" << KProcess::quote( m_diffSettings->m_excludeFilesFileURL );
+		*this << "-X" << m_diffSettings->m_excludeFilesFileURL;
 	}
 }
 
 KompareProcess::~KompareProcess()
 {
+	delete m_textDecoder;
 }
 
 void KompareProcess::setEncoding( const QString& encoding )
 {
-	if ( encoding.lower() == "default" )
+	if ( !encoding.compare( "default", Qt::CaseInsensitive ) )
 	{
 		m_textDecoder = QTextCodec::codecForLocale()->makeDecoder();
 	}
@@ -219,50 +218,44 @@ void KompareProcess::setEncoding( const QString& encoding )
 			m_textDecoder = textCodec->makeDecoder();
 		else
 		{
-			kdDebug(8101) << "Using locale codec as backup..." << endl;
+			kDebug(8101) << "Using locale codec as backup..." << endl;
 			textCodec = QTextCodec::codecForLocale();
 			m_textDecoder = textCodec->makeDecoder();
 		}
 	}
 }
 
-void KompareProcess::slotReceivedStdout( KProcess* /* process */, char* buffer, int length )
-{
-	// add all output to m_stdout
-	if ( m_textDecoder )
-		m_stdout += m_textDecoder->toUnicode( buffer, length );
-	else
-		kdDebug(8101) << "KompareProcess::slotReceivedStdout : No decoder !!!" << endl;
-}
-
-void KompareProcess::slotReceivedStderr( KProcess* /* process */, char* buffer, int length )
-{
-	// add all output to m_stderr
-	if ( m_textDecoder )
-		m_stderr += m_textDecoder->toUnicode( buffer, length );
-	else
-		kdDebug(8101) << "KompareProcess::slotReceivedStderr : No decoder !!!" << endl;
-}
-
-bool KompareProcess::start()
+void KompareProcess::start()
 {
 #ifndef NDEBUG
 	QString cmdLine;
-	QValueList<QCString>::ConstIterator it = arguments.begin();
-	for (; it != arguments.end(); ++it )
+	QStringList program = KProcess::program();
+	QStringList::ConstIterator it = program.begin();
+	for (; it != program.end(); ++it )
 	    cmdLine += "\"" + (*it) + "\" ";
-	kdDebug(8101) << cmdLine << endl;
+	kDebug(8101) << cmdLine << endl;
 #endif
-	return( KProcess::start( KProcess::NotifyOnExit, KProcess::AllOutput ) );
+	setOutputChannelMode( SeparateChannels );
+	setNextOpenMode( ReadOnly );
+	KProcess::start();
 }
 
-void KompareProcess::slotProcessExited( KProcess* /* proc */ )
+void KompareProcess::slotFinished( int exitCode, QProcess::ExitStatus exitStatus )
 {
-	// exit status of 0: no differences
-	//                1: some differences
-	//                2: error but there may be differences !
-	kdDebug(8101) << "Exited with exit status : " << exitStatus() << endl;
-	emit diffHasFinished( normalExit() && exitStatus() != 0 );
+	// add all output to m_stdout/m_stderr
+	if ( m_textDecoder )
+	{
+		m_stdout = m_textDecoder->toUnicode( readAllStandardOutput() );
+		m_stderr = m_textDecoder->toUnicode( readAllStandardError() );
+	}
+	else
+		kDebug(8101) << "KompareProcess::slotFinished : No decoder !!!" << endl;
+
+	// exit code of 0: no differences
+	//              1: some differences
+	//              2: error but there may be differences !
+	kDebug(8101) << "Exited with exit code : " << exitCode << endl;
+	emit diffHasFinished( exitStatus == NormalExit && exitCode != 0 );
 }
 
 #include "kompareprocess.moc"
