@@ -42,8 +42,9 @@ class FlowLayout;
 class QDragEnterEvent;
 class QDropEvent;
 class QEvent;
-class QAction;
+class KAction;
 class QFrame;
+class QScrollArea;
 #include <QVector>
 
 namespace GlossaryNS {
@@ -55,7 +56,7 @@ class GlossaryView: public QDockWidget
     Q_OBJECT
 
 public:
-    GlossaryView(QWidget*,Catalog*,const QVector<QAction*>&);
+    GlossaryView(QWidget*,Catalog*,const QVector<KAction*>&);
     virtual ~GlossaryView();
 
 
@@ -64,13 +65,13 @@ public:
 //     bool event(QEvent*);
 public slots:
     //plural messages usually contain the same words...
-    void slotNewEntryDisplayed(uint entry=0xffffffff);//a little hacky, but... :)
+    void slotNewEntryDisplayed(DocPosition pos=DocPosition());//a little hacky, but... :)
 
 signals:
     void termInsertRequested(const QString&);
 
 private:
-    QFrame* m_browser;
+    QScrollArea* m_browser;
     Catalog* m_catalog;
     FlowLayout *m_flowLayout;
     Glossary* m_glossary;
