@@ -1,7 +1,7 @@
 /* ****************************************************************************
-  This file is part of KAider
+  This file is part of Lokalize
 
-  Copyright (C) 2007 by Nick Shaforostoff <shafff@ukr.net>
+  Copyright (C) 2007-2008 by Nick Shaforostoff <shafff@ukr.net>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -37,11 +37,13 @@
 #include "catalog.h"
 #include "pos.h"
 #include "cmd.h"
+#include "project.h"
 #include "prefs_lokalize.h"
 #include "ui_kaider_findextension.h"
 
 
 #include <kglobal.h>
+#include <kmessagebox.h>
 #include <klocale.h>
 #include <kdebug.h>
 #include <kurl.h>
@@ -52,40 +54,57 @@
 #include <kreplace.h>
 
 #include <sonnet/backgroundchecker.h>
+#include <sonnet/dialog.h>
 
 #include <QTimer>
 
 
-//  #include "global.h"
-
 //#define FIND_IGNOREACCELS 2048
 //#define FIND_SKIPTAGS 4096
 #define FIND_IGNOREACCELS ui_findExtension->m_ignoreAccelMarks->isChecked()
 #define FIND_SKIPTAGS ui_findExtension->m_skipTags->isChecked()
 #define REPLACE_IGNOREACCELS ui_replaceExtension->m_ignoreAccelMarks->isChecked()
 
-void KAider::deleteUiSetupers()
+void EditorWindow::deleteUiSetupers()
 {
     delete ui_findExtension;
     delete ui_replaceExtension;
 }
 
-static void cleanUpIfMultiple(KAider* th,
+static void cleanUpIfMultiple(EditorWindow* th,
                               KUrl::List& list,
                               int& pos,
                               KFindDialog* dia)
 {
-    if (!list.isEmpty())
-    {
-        if (!th->isVisible())
-            th->deleteLater();
-        list.clear();
-        pos=-1;
-        dia->setHasCursor(true);
-    }
+    if (list.isEmpty())
+        return;
+
+    if (!th->isVisible())
+        th->deleteLater();
+    list.clear();
+    pos=-1;
+    dia->setHasCursor(true);
 }
 
-void KAider::find()
+//TODO &amp;, &nbsp;
+static void calsOffsetWithAccels(const QString& data, int& offset, int& length)
+{
+    int i=0;
+    for (;i<offset;++i)
+        if (KDE_ISUNLIKELY( data.at(i)=='&' ))
+            ++offset;
+
+    //if & is inside highlighted word
+    int limit=offset+length;
+    for (i=offset;i<limit;++i)
+        if (KDE_ISUNLIKELY( data.at(i)=='&' ))
+        {
+            ++length;
+            limit=qMin(data.size(),offset+length);//just safety
+        }
+}
+
+void EditorWindow::find()
 {
     if(KDE_ISUNLIKELY( !_findDialog ))
     {
@@ -168,7 +187,7 @@ void KAider::find()
     findNext(pos);
 }
 
-bool KAider::determineStartingPos(KFind* find,
+bool EditorWindow::determineStartingPos(KFind* find,
                                   const KUrl::List& filesList,//search or replace files
                                   int& filesPos,
                                   DocPosition& pos)
@@ -183,7 +202,7 @@ bool KAider::determineStartingPos(KFind* find,
             {
                 m_updateView=false;
             }
-            if ((find==_replace&&!fileSave())
+            if ((find==_replace&&!saveFile())
                ||!fileOpen(filesList.at(filesPos)))
                 return false;
             if (filesList.size()!=1)
@@ -195,7 +214,7 @@ bool KAider::determineStartingPos(KFind* find,
 
         pos.entry=_catalog->numberOfEntries()-1;
         pos.form=
-                (_catalog->pluralFormType(pos.entry)==Gettext)?
+                (_catalog->isPlural(pos.entry))?
                 _catalog->numberOfPluralForms()-1:0;
 
     }
@@ -209,7 +228,7 @@ bool KAider::determineStartingPos(KFind* find,
             {
                 m_updateView=false;
             }
-            if ((find==_replace&&!fileSave())
+            if ((find==_replace&&!saveFile())
                ||!fileOpen(filesList.at(filesPos)))
                 return false;
             if (filesList.size()!=1)
@@ -226,12 +245,12 @@ bool KAider::determineStartingPos(KFind* find,
     return true;
 }
 
-// void KAider::initProgressDia()
+// void EditorWindow::initProgressDia()
 // {
 //     
 // }
 
-void KAider::findNext(const DocPosition& startingPos)
+void EditorWindow::findNext(const DocPosition& startingPos)
 {
     Catalog& catalog=*_catalog;
     KFind& find=*_find;
@@ -283,20 +302,22 @@ void KAider::findNext(const DocPosition& startingPos)
         KFind::Result res = KFind::NoMatch;
         while (true)
         {
-            if (find.needData()||anotherEntry||m_modifiedAfterFind)
+            if (find.needData()||anotherEntry||m_view->m_modifiedAfterFind)
             {
                 anotherEntry=false;
-                m_modifiedAfterFind=false;
+                m_view->m_modifiedAfterFind=false;
 
                 QString data;
                 if (_searchingPos.part==Msgid)
                 {
                     data=catalog.msgid(_searchingPos)/*,offset*/;
 
+#ifdef UNWRAP_MSGID
                     //unwrap bc kaiderview does that too
                     int p=0;
                     while ((p=rx.indexIn(data))!=-1)
                         data.remove(p+1,1);
+#endif
                 }
                 else
                     data=catalog.msgstr(_searchingPos)/*,offset*/;
@@ -349,7 +370,7 @@ void KAider::findNext(const DocPosition& startingPos)
                         {
                             DocPosition pos;
                             pos.entry=catalog.numberOfEntries()-1;
-                            pos.form=(catalog.pluralFormType(pos.entry)==Gettext)?
+                            pos.form=(catalog.isPlural(pos.entry))?
                                 catalog.numberOfPluralForms()-1:0;
                             //_searchingPos=pos;
                             gotoEntry(pos);
@@ -362,7 +383,6 @@ void KAider::findNext(const DocPosition& startingPos)
                         QTimer::singleShot(0,this,SLOT(findNext()));
                         //hideDia=false;
 
-                        kWarning()<<"searchink         TIME "<<a.elapsed();
                         return;
                     }
                     else
@@ -398,10 +418,9 @@ void KAider::findNext(const DocPosition& startingPos)
         m_progressDialog->hide();
 
     m_catalogTreeView->setUpdatesEnabled(true);
-    kWarning()<<"searchink         TIME "<<a.elapsed();
 }
 
-void KAider::findNext()
+void EditorWindow::findNext()
 {
     if (_find)
         findNext(_currentPos);
@@ -410,7 +429,7 @@ void KAider::findNext()
 
 }
 
-void KAider::findPrev()
+void EditorWindow::findPrev()
 {
 
     if (_find)
@@ -425,11 +444,9 @@ void KAider::findPrev()
 
 }
 
-void KAider::highlightFound(const QString &,int matchingIndex,int matchedLength)
+void EditorWindow::highlightFound(const QString &,int matchingIndex,int matchedLength)
 {
-    show();
-    kWarning()<<"matchingIndex"<<matchingIndex
-            <<"matchedLength"<<matchedLength;
+    show();//for search through several files
 
     if (FIND_IGNOREACCELS)
     {
@@ -438,18 +455,8 @@ void KAider::highlightFound(const QString &,int matchingIndex,int matchedLength)
             data=_catalog->msgid(_searchingPos);
         else
             data=_catalog->msgstr(_searchingPos);
-        int i=0;
-        for (;i<matchingIndex;++i)
-            if (KDE_ISUNLIKELY( data.at(i)=='&' ))
-                ++matchingIndex;
 
-        int limit=matchingIndex+matchedLength;
-        for (i=matchingIndex;i<limit;++i)
-            if (KDE_ISUNLIKELY( data.at(i)=='&' ))
-            {
-                ++matchedLength;
-                limit=qMin(data.size(),matchingIndex+matchedLength);
-            }
+        calsOffsetWithAccels(data, matchingIndex, matchedLength);
     }
 
     _searchingPos.offset=matchingIndex;
@@ -457,7 +464,7 @@ void KAider::highlightFound(const QString &,int matchingIndex,int matchedLength)
 
 }
 
-void KAider::replace()
+void EditorWindow::replace()
 {
     if( !_replaceDialog )
     {
@@ -510,9 +517,7 @@ void KAider::replace()
 
 
     if (_replace)
-    {
-        delete _replace; _replace=0;
-    }
+        _replace->deleteLater();// _replace=0;
 
     // This creates a find-next-prompt dialog if needed.
     {
@@ -552,11 +557,10 @@ void KAider::replace()
         replaceNext(pos);
     }
 
-//     kWarning() << "END";
 }
 
 
-void KAider::replaceNext(const DocPosition& startingPos)
+void EditorWindow::replaceNext(const DocPosition& startingPos)
 {
     bool anotherEntry=_replacingPos.entry!=_replacingPos.entry;
     _replacingPos=startingPos;
@@ -595,9 +599,10 @@ void KAider::replaceNext(const DocPosition& startingPos)
         KFind::Result res=KFind::NoMatch;
         while (1)
         {
-            if (_replace->needData()||anotherEntry)
+            if (_replace->needData()||anotherEntry/*||m_view->m_modifiedAfterFind*/)
             {
                 anotherEntry=false;
+                //m_view->m_modifiedAfterFind=false;//NOTE TEST THIS
 
                 if (REPLACE_IGNOREACCELS)
                 {
@@ -609,7 +614,6 @@ void KAider::replaceNext(const DocPosition& startingPos)
                     _replace->setData( _catalog->msgstr(_replacingPos));
             }
             res = _replace->replace();
-//             offset=-1;
             if (res!=KFind::NoMatch)
                 break;
 
@@ -647,7 +651,7 @@ void KAider::replaceNext(const DocPosition& startingPos)
                     {
                         m_updateView=false;
                     }
-                    if (!fileSave()
+                    if (!saveFile()
                        ||fileOpen(m_replaceFiles.at(m_replaceFilesPos)))
                     {
                         cleanUpIfMultiple(this,
@@ -660,7 +664,7 @@ void KAider::replaceNext(const DocPosition& startingPos)
                     {
                         DocPosition pos;
                         pos.entry=_catalog->numberOfEntries()-1;
-                        pos.form=(_catalog->pluralFormType(pos.entry)==Gettext)?
+                        pos.form=(_catalog->isPlural(pos.entry))?
                             _catalog->numberOfPluralForms()-1:0;
                         //_searchingPos=pos;
                         gotoEntry(pos);
@@ -695,12 +699,11 @@ void KAider::replaceNext(const DocPosition& startingPos)
                                   m_replaceFilesPos,
                                   _replaceDialog);
 
-//HACK avoid crash
-//                 _replace->closeReplaceNextDialog();
-
                 if(!(_replace->options() & KFind::FromCursor))
                      _replace->displayFinalDialog();
 
+                _replace->closeReplaceNextDialog();
+
                 if(m_doReplaceCalled)
                 {
                     m_doReplaceCalled=false;
@@ -717,13 +720,12 @@ void KAider::replaceNext(const DocPosition& startingPos)
     m_catalogTreeView->setUpdatesEnabled(true);
 }
 
-void KAider::replaceNext()
+void EditorWindow::replaceNext()
 {
     replaceNext(_currentPos);
-//     kWarning() << "END";
 }
 
-void KAider::highlightFound_(const QString &,int matchingIndex,int matchedLength)
+void EditorWindow::highlightFound_(const QString &,int matchingIndex,int matchedLength)
 {
     show();
 
@@ -734,18 +736,7 @@ void KAider::highlightFound_(const QString &,int matchingIndex,int matchedLength
             data=_catalog->msgid(_replacingPos);
         else
             data=_catalog->msgstr(_replacingPos);
-        int i=0;
-        for (;i<matchingIndex;++i)
-            if (data.at(i)=='&')
-                ++matchingIndex;
-
-        int limit=matchingIndex+matchedLength;
-        for (i=matchingIndex;i<matchingIndex+matchedLength;++i)
-            if (data.at(i)=='&')
-            {
-                ++matchedLength;
-                limit=qMin(data.size(),matchingIndex+matchedLength);
-            }
+        calsOffsetWithAccels(data,matchingIndex,matchedLength);
     }
 
     _replacingPos.offset=matchingIndex;
@@ -754,7 +745,7 @@ void KAider::highlightFound_(const QString &,int matchingIndex,int matchedLength
 }
 
 
-void KAider::doReplace(const QString &newStr,int offset,int newLen,int remLen)
+void EditorWindow::doReplace(const QString &newStr,int offset,int newLen,int remLen)
 {
     if(!m_doReplaceCalled)
     {
@@ -764,20 +755,7 @@ void KAider::doReplace(const QString &newStr,int offset,int newLen,int remLen)
     QString oldStr(_catalog->target(_replacingPos));
 
     if (REPLACE_IGNOREACCELS)
-    {
-        int i=0;
-        for (;i<offset;++i)
-            if (oldStr.at(i)=='&')
-                ++offset;
-
-        int limit=offset+remLen;
-        for (i=offset;i<limit;++i)
-            if (oldStr.at(i)=='&')
-            {
-                ++remLen;
-                limit=qMin(oldStr.size(),offset+remLen);
-            }
-    }
+        calsOffsetWithAccels(oldStr,offset,remLen);
 
     QString tmp(oldStr.mid(offset,remLen));
 //     if (tmp==_replaceDialog->pattern())
@@ -817,20 +795,26 @@ void KAider::doReplace(const QString &newStr,int offset,int newLen,int remLen)
 
 
 
-void KAider::spellcheck()
+void EditorWindow::spellcheck()
 {
     if (!m_sonnetDialog)
     {
-        m_sonnetDialog=new Sonnet::Dialog(
-            new Sonnet::BackgroundChecker( this ),
-            this );
-        connect(m_sonnetDialog,SIGNAL(done(const QString&)),this,SLOT(spellcheckNext()));
-        connect(m_sonnetDialog,SIGNAL(replace(const QString&,int,const QString&)),
-            this,SLOT(spellcheckReplace(const QString&,int,const QString&)));
-        connect(m_sonnetDialog,SIGNAL(misspelling(const QString&,int)),
-            this,SLOT(spellcheckShow(const QString&,int)));
+        m_sonnetChecker=new Sonnet::BackgroundChecker(this);
+        m_sonnetDialog=new Sonnet::Dialog(m_sonnetChecker,this);
+        connect(m_sonnetDialog,SIGNAL(done(QString)),this,SLOT(spellcheckNext()));
+        connect(m_sonnetDialog,SIGNAL(replace(QString,int,QString)),
+            this,SLOT(spellcheckReplace(QString,int,QString)));
         connect(m_sonnetDialog,SIGNAL(stop()),this,SLOT(spellcheckStop()));
         connect(m_sonnetDialog,SIGNAL(cancel()),this,SLOT(spellcheckCancel()));
+
+        connect(m_sonnetDialog/*m_sonnetChecker*/,SIGNAL(misspelling(QString,int)),
+            this,SLOT(spellcheckShow(QString,int)));
+//         disconnect(/*m_sonnetDialog*/m_sonnetChecker,SIGNAL(misspelling(QString,int)),
+//             m_sonnetDialog,SLOT(slotMisspelling(QString,int)));
+// 
+//     connect( d->checker, SIGNAL(misspelling(const QString&, int)),
+//              SLOT(slotMisspelling(const QString&, int)) );
+
     }
 
     if (!m_spellcheckFiles.isEmpty()
@@ -845,10 +829,11 @@ void KAider::spellcheck()
         m_spellcheckFilesPos=0;
     }
 
+    QString text=_catalog->msgstr(_currentPos);
     if (!m_view->selection().isEmpty())
-        m_sonnetDialog->setBuffer(m_view->selection());
-    else
-        m_sonnetDialog->setBuffer(_catalog->msgstr(_currentPos));
+        text=m_view->selection();
+    text.remove('&');
+    m_sonnetDialog->setBuffer(text);
 
     _spellcheckPos=_currentPos;
     _spellcheckStop=false;
@@ -859,21 +844,19 @@ void KAider::spellcheck()
 }
 
 
-void KAider::spellcheckNext()
+void EditorWindow::spellcheckNext()
 {
-    //DocPosition pos=_spellcheckPos;
-
     if (!_spellcheckStop && switchNext(_catalog,_spellcheckPos))
     {
         // HACK actually workaround
-        while (_catalog->msgstr(_spellcheckPos).isEmpty())
+        while (_catalog->msgstr(_spellcheckPos).isEmpty() || !_catalog->isApproved(_spellcheckPos.entry))
         {
             if (!switchNext(_catalog,_spellcheckPos))
             {
                 if (m_spellcheckFiles.isEmpty())
                     return;
                 if (++m_spellcheckFilesPos==m_spellcheckFiles.size()
-                    ||!fileSave()
+                    ||!saveFile()
                     ||!fileOpen(m_spellcheckFiles.at(m_spellcheckFilesPos)))
                 {
                     m_spellcheckFiles.clear();
@@ -885,39 +868,54 @@ void KAider::spellcheckNext()
                 QTimer::singleShot(0,this,SLOT(spellcheck()));
                 return;
             }
-        m_sonnetDialog->setBuffer( _catalog->msgstr(_spellcheckPos) );
-//             kWarning() << "spellcheckNext a"<<_catalog->msgstr(_spellcheckPos);
-
         }
+        QString text=_catalog->msgstr(_spellcheckPos);
+        text.remove('&');
+        m_sonnetDialog->setBuffer(text);
     }
 }
 
-void KAider::spellcheckStop()
+void EditorWindow::spellcheckStop()
 {
     _spellcheckStop=true;
 }
 
-void KAider::spellcheckCancel()
+void EditorWindow::spellcheckCancel()
 {
     _catalog->setIndex(_spellcheckStartUndoIndex);
     gotoEntry(_spellcheckPos);
 }
 
-void KAider::spellcheckShow(const QString &word, int offset)
+void EditorWindow::spellcheckShow(const QString &word, int offset)
 {
+    QString source=_catalog->source(_spellcheckPos);
+    source.remove('&');
+    if (source.contains(word))
+    {
+        m_sonnetDialog->setUpdatesEnabled(false);
+        m_sonnetChecker->continueChecking();
+        return;
+    }
+    m_sonnetDialog->setUpdatesEnabled(true);
+
     show();
 
-//     kWarning() << "spellcheckShw "<<word;
     DocPosition pos=_spellcheckPos;
+    int length=word.length();
+    calsOffsetWithAccels(_catalog->target(pos),offset,length);
     pos.offset=offset;
-    gotoEntry(pos,word.length());
-//     kWarning() << "spellcheckShw "<<word;
+
+    gotoEntry(pos,length);
 }
 
-void KAider::spellcheckReplace(const QString &oldWord, int offset, const QString &newWord)
+void EditorWindow::spellcheckReplace(QString oldWord, int offset, const QString &newWord)
 {
     DocPosition pos=_spellcheckPos;
+    int length=oldWord.length();
+    calsOffsetWithAccels(_catalog->target(pos),offset,length);
     pos.offset=offset;
+    if (length>oldWord.length())//replaced word contains accel mark
+        oldWord=_catalog->target(pos).mid(offset,length);
 
     _catalog->push(new DelTextCmd(_catalog,pos,oldWord));
     _catalog->push(new InsTextCmd(_catalog,pos,newWord));
@@ -937,7 +935,7 @@ void KAider::spellcheckReplace(const QString &oldWord, int offset, const QString
 
 
 
-void KAider::findInFiles(const KUrl::List& list)
+void EditorWindow::findInFiles(const KUrl::List& list)
 {
     m_searchFiles=list;
     m_searchFilesPos=-1;
@@ -962,7 +960,7 @@ this is nice, but too complex :)
 }
 
 
-void KAider::replaceInFiles(const KUrl::List& list)
+void EditorWindow::replaceInFiles(const KUrl::List& list)
 {
     m_replaceFiles=list;
     m_replaceFilesPos=-1;
@@ -971,7 +969,7 @@ void KAider::replaceInFiles(const KUrl::List& list)
 }
 
 
-void KAider::spellcheckFiles(const KUrl::List& list)
+void EditorWindow::spellcheckFiles(const KUrl::List& list)
 {
     m_spellcheckFiles=list;
     m_spellcheckFilesPos=-1;
@@ -981,5 +979,47 @@ void KAider::spellcheckFiles(const KUrl::List& list)
 
 
 
+bool EditorWindow::findEntryBySourceContext(const QString& source, const QString& ctxt)
+{
+    DocPosition pos(0);
+    do
+    {
+        if (_catalog->source(pos)==source && _catalog->msgctxt(pos.entry)==ctxt)
+        {
+            gotoEntry(pos);
+            return true;
+        }
+    }
+    while (switchNext(_catalog,pos));
+    return false;
+}
+
+
+void EditorWindow::displayWordCount()
+{
+    //TODO in trans and fuzzy separately
+    int sourceCount=0;
+    int targetCount=0;
+    QRegExp rxClean(Project::instance()->markup()+'|'+Project::instance()->accel());//cleaning regexp; NOTE isEmpty()?
+    QRegExp rxSplit("\\W|\\d");//splitting regexp
+    DocPosition pos(0);
+    do
+    {
+        QString msg=_catalog->source(pos);
+        msg.remove(rxClean);
+        QStringList words=msg.split(rxSplit,QString::SkipEmptyParts);
+        sourceCount+=words.size();
+
+        msg=_catalog->target(pos);
+        msg.remove(rxClean);
+        words=msg.split(rxSplit,QString::SkipEmptyParts);
+        targetCount+=words.size();
+    }
+    while (switchNext(_catalog,pos));
+
+    KMessageBox::information(this, i18nc("@info words count",
+                            "Source text words: %1<br/>Target text words: %2",
+                                        sourceCount,targetCount),i18nc("@title","Word Count"));
+}
 
 
