@@ -5,15 +5,29 @@
 #include <stdlib.h>
 #include <assert.h>
 #include <qregexp.h>
+//Added by qt3to4:
+#include <QTextStream>
+#include <Q3CString>
 
 using namespace std;
 
+static int countRev( const QString & str, QChar ch, int idx ) {
+    if ( idx < 0 )
+        idx += str.length();
+    if ( idx >= str.length() )
+        idx = str.length();
+    int count = 0;
+    for ( int i = 0 ; i <= idx ; ++i )
+        count += ( str[i] == ch );
+    return count;
+}
+
 static const char *singletags[] = {"beginpage","imagedata", "colspec", "spanspec",
                                    "anchor", "xref", "area",
                                    "footnoteref", "void", "inlinegraphic",
                                    "glosssee", "graphic", "xi:include",
                                    0};
-static const char *cuttingtags[] = {"bridgehead", "appendix", "trans_comment", "para", "title", "term",
+static const char *cuttingtags[] = {"bridgehead", "trans_comment", "para", "title", "term",
                                     "entry", "contrib", "keyword", "example",
                                     "note", "footnote", "caution",
                                     "informalexample", "remark", "comment",
@@ -41,7 +55,7 @@ static const char *cuttingtags[] = {"bridgehead", "appendix", "trans_comment", "
                                     "refmiscinfo", "refsect2", "refsect3", "refsect1info",
                                     "refsect2info", "refsect3info", "refsection", "refsectioninfo",
                                     "refsynopsisdiv", "refsysnopsisdivinfo", "remark",
-                                    "revdescription", "glossentry", "partinfo", 
+                                    "revdescription", "glossentry", "partinfo",
 				    "segmentedlist", "segtitle", "seg", "seglistitem", "screenco",
                                     0};
 static const char *literaltags[] = {"literallayout", "synopsis", "screen",
@@ -113,7 +127,7 @@ bool StructureParser::startElement( const QString& , const QString& ,
 
     if (isCuttingTag(tname)) {
         if (!inside) {
-            message = QString::null;
+            message = QString();
             list.pc.increasePara();
             startline = locator->lineNumber();
             startcol = locator->columnNumber();
@@ -124,7 +138,7 @@ bool StructureParser::startElement( const QString& , const QString& ,
 
     if (inside)
     {
-        QString tmp = "<" + tname;
+        QString tmp = '<' + tname;
         for (int i = 0; i < attr.length(); i++) {
             tmp += QString(" %1=\"%2\"").arg(attr.qName(i)).arg(attr.value(i));
         }
@@ -134,7 +148,7 @@ bool StructureParser::startElement( const QString& , const QString& ,
         if (isSingleTag(qName))
             tmp += "/>";
         else
-            tmp += ">";
+            tmp += '>';
         message += tmp;
         if (first)
             startcol -= message.length();
@@ -177,7 +191,7 @@ bool StructureParser::closureTag(const QString& message, const QString &tag)
 #endif
 
     int inside = 0;
-    uint index = 0;
+    int index = 0;
     while (true)
     {
         int nextclose = message.find(QRegExp(QString::fromLatin1("</%1[\\s>]").arg(tag)), index);
@@ -216,7 +230,7 @@ bool StructureParser::closureTag(const QString& message, const QString &tag)
 
 void StructureParser::descape(QString &message)
 {
-    uint index = 0;
+    int index = 0;
     stripWhiteSpace( message );
 
     int inside = 0;
@@ -235,7 +249,7 @@ void StructureParser::descape(QString &message)
                 lastws = true;
                 break;
             case '<': {
-                uint endindex = index+1;
+                int endindex = index+1;
                 while (endindex < message.length() && !message.at(endindex).isSpace() &&
                        message.at(endindex) != '>')
                     endindex++;
@@ -254,7 +268,7 @@ void StructureParser::descape(QString &message)
 
         index++;
     }
-    message.replace(QRegExp("\010"), "");
+    message.remove(QRegExp("\010"));
 }
 
 bool StructureParser::formatMessage(MsgBlock &msg) const
@@ -290,7 +304,7 @@ bool StructureParser::formatMessage(MsgBlock &msg) const
             msg.msgid = msg.msgid.mid(strindex + 1);
             changed = true;
             offset += strindex + 1;
-            for (int index = 0; msg.msgid.at(index) == ' '; index++, offset++) ;
+            for (int index = 0; index < msg.msgid.length() && msg.msgid.at(index) == ' '; index++, offset++) ;
             stripWhiteSpace( msg.msgid );
         }
     }
@@ -305,11 +319,11 @@ bool StructureParser::formatMessage(MsgBlock &msg) const
         changed = true;
     }
 
-    for (int index = 0; msg.msgid.at(index) == ' '; index++, offset++) ;
+    for (int index = 0; index < msg.msgid.length() && msg.msgid.at(index) == ' '; index++, offset++) ;
     stripWhiteSpace( msg.msgid );
 
     while (true) {
-        if (msg.msgid.at(0) != '<')
+        if (msg.msgid.isEmpty() || msg.msgid.at(0) != '<')
             break;
         if (msg.msgid.at(msg.msgid.length() - 1) != '>')
             break;
@@ -328,7 +342,7 @@ bool StructureParser::formatMessage(MsgBlock &msg) const
 
         QString endtag = msg.msgid.mid(endindex + 2, msg.msgid.length() - (endindex + 2) - 1);
         QString endtag_attr = endtag.mid(endtag.find(' '), endtag.length());
-        endtag.replace(infos_reg, "");
+        endtag.remove(infos_reg);
         if (endtag == starttag) {
             if (!closureTag(msg.msgid, starttag))
                 break;
@@ -341,7 +355,7 @@ bool StructureParser::formatMessage(MsgBlock &msg) const
             QString attr = msg.msgid.left(strindex);
             msg.msgid = msg.msgid.mid(strindex + 1);
             offset += strindex + 1;
-            for (int index = 0; msg.msgid.at(index) == ' '; index++, offset++) ;
+            for (int index = 0; index < msg.msgid.length() && msg.msgid.at(index) == ' '; index++, offset++) ;
             stripWhiteSpace( msg.msgid );
             msg.tag = starttag;
 
@@ -395,7 +409,7 @@ MsgList StructureParser::splitMessage(const MsgBlock &mb)
     qDebug("splitMessage %s", message.latin1());
 #endif
 
-    if (message.at(0) == '<') {
+    if (!message.isEmpty() && message.at(0) == '<') {
         int endindex = 1;
         while (!message.at(endindex).isSpace() && message.at(endindex) != '>')
             endindex++;
@@ -504,7 +518,7 @@ MsgList StructureParser::splitMessage(const MsgBlock &mb)
 
     }
 
-    if (message.at(message.length() - 1 ) == '>')
+    if (!message.isEmpty() && message.at(message.length() - 1 ) == '>')
     {
         int endindex = message.length() - 1;
         while (endindex >= 0 && (message.at(endindex) != '<' || message.at(endindex + 1) != '/'))
@@ -604,7 +618,7 @@ bool StructureParser::endElement( const QString& , const QString&, const QString
             message += QString("</%1").arg(tname);
             message += QString(" poxml_line=\"%1\"").arg(locator->lineNumber());
             message += QString(" poxml_col=\"%1\"").arg(locator->columnNumber());
-            message += ">";
+            message += '>';
         }
     }
 
@@ -620,7 +634,8 @@ bool StructureParser::endElement( const QString& , const QString&, const QString
             bi.start_col = startcol;
             bi.end_line = locator->lineNumber();
             bi.end_col = locator->columnNumber() + 1;
-            bi.offset = m.lines.first().offset;
+            if (m.lines.isEmpty()) bi.offset = 0;
+            else bi.offset = m.lines.first().offset;
             m.lines.append(bi);
             formatMessage(m);
 
@@ -633,14 +648,14 @@ bool StructureParser::endElement( const QString& , const QString&, const QString
 #endif
                 // if the remaining text still starts with a tag, the poxml_ info
                 // is most probably more correct
-                if ((*it).msgid.at(0) == '<' && isClosure((*it).msgid)) {
+                if (!(*it).msgid.isEmpty() && (*it).msgid.at(0) == '<' && isClosure((*it).msgid)) {
                     if (infos_reg.search((*it).msgid) >= 0) {
                         (*it).lines.first().start_line = infos_reg.cap(1).toInt();
                         (*it).lines.first().start_col =  infos_reg.cap(2).toInt();;
                         (*it).lines.first().offset = 0;
                     }
                 }
-                (*it).msgid.replace(infos_reg, QString::null);
+                (*it).msgid.replace(infos_reg, QString());
 
                 if (!(*it).msgid.isEmpty())
                     list.append(*it);
@@ -895,7 +910,7 @@ QString escapePO(QString msgid)
         index = msgid.find("\\t", index);
         if (index == -1)
             break;
-        if (msgid.at(index - 1) == '\\')
+        if (index > 0 && msgid.at(index - 1) == '\\')
             msgid.replace(index - 1, 3, "\\t");
         else
             msgid.replace(index, 2, "\t");
@@ -919,16 +934,46 @@ MsgList parseXML(const char *filename)
 {
     StructureParser handler;
     QFile xmlFile( filename );
-    xmlFile.open(IO_ReadOnly);
+    xmlFile.open(QIODevice::ReadOnly);
 
-    QCString ccontents;
-    ccontents.fill(0, xmlFile.size() + 1);
-    memcpy(ccontents.data(), xmlFile.readAll().data(), xmlFile.size());
+    QByteArray ccontents = xmlFile.readAll();
     xmlFile.close();
 
     QString contents = QString::fromUtf8( ccontents );
     StructureParser::cleanupTags(contents);
 
+    MsgList english;
+    {
+        // find internal entities that start with "i18n-", and extract
+        // their replacement texts:
+        QRegExp rx( "<!ENTITY\\s+([^\\s]+)\\s+([\"'])" );
+        for ( int index = rx.indexIn( contents, 0 ) ; index >= 0 ; index = rx.indexIn( contents, index ) ) {
+            const QString name = rx.cap( 1 );
+            const QChar delim = rx.cap( 2 ).at( 0 );
+            const int start = index;
+            index = contents.indexOf( delim, index + rx.matchedLength() );
+            index = contents.indexOf( '>', index );
+            if ( !name.startsWith( "i18n-" ) )
+                continue;
+            const QString entity = contents.mid( start, index - start + 1 );
+            MsgBlock block;
+            block.tag = "!ENTITY";
+            BlockInfo bi;
+            bi.start_line = countRev( contents, '\n', index ) + 1;
+            bi.start_col  = start - contents.lastIndexOf( '\n', start ) - 1;
+            bi.end_line   = bi.start_line + entity.count( '\n' );
+            bi.end_col    = index - contents.lastIndexOf( '\n', index ) + 1;
+#ifdef POXML_DEBUG
+            qDebug( "ENTITY %s @ i:%d l:%d c:%d->l:%d c:%d", qPrintable( name ),
+                    index, bi.start_line, bi.start_col, bi.end_line, bi.end_col );
+#endif
+            block.lines.push_back( bi );
+            block.msgid = entity;
+            english.push_back( block );
+        }
+    }
+
+    // Remove all entity definitions now:
     while (true) {
         int index = contents.find("<!ENTITY");
         if (index < 0)
@@ -955,7 +1000,7 @@ MsgList parseXML(const char *filename)
         contents.replace(index, endindex - index, replacement);
     }
 
-    QTextStream ts(contents.utf8(), IO_ReadOnly);
+    QTextStream ts(contents.utf8(), QIODevice::ReadOnly);
     QXmlInputSource source( ts );
     QXmlSimpleReader reader;
     reader.setFeature( "http://trolltech.com/xml/features/report-start-end-entity", true);
@@ -964,7 +1009,7 @@ MsgList parseXML(const char *filename)
     reader.setDTDHandler( &handler );
     // reader.setErrorHandler( &handler );
     reader.parse( source );
-    MsgList english = handler.getList();
+    english += handler.getList();
 
     bool changed = false;
 
