@@ -171,9 +171,13 @@ This function does not do any hidden buffer changes."
     (setq function (replace-match " " t t function)))
   (while (string-match "^ " function)  ; remove leading whitespace
     (setq function (replace-match "" t t function)))
+  ; remove default values. complex case: void foo(p=QString())
   (let ((startargs (string-match "(" function)))
-    (while (string-match " ?=[^,)]+" function startargs) ; remove default values
-      (setq function (replace-match " " t t function))))
+    (while (string-match " ?=[^,()]+" function startargs) ; part 1 (stop at '(')
+      (setq function (replace-match "" t t function)))
+    (while (string-match "([^()]*)" function (+ startargs 1))       ; part 2, remove "(...)"
+      (setq function (replace-match "" t t function))))
+
   (while (string-match " +," function) ; remove space before commas
     (setq function (replace-match "," t t function)))
   function ; the return value
@@ -272,7 +276,7 @@ This function does not do any hidden buffer changes."
               )
             )
           ))
-    (if (string-match "\\.h$" n)
+    (if (member (concat "." (file-name-extension n)) sourcepair-header-extensions)
         (progn
 	  (let ((mup (method-under-point))
 		(sig "")
@@ -445,10 +449,15 @@ This function does not do any hidden buffer changes."
 (defun insert-kDebug ()
   (interactive)
   (if (and (boundp 'kdab-qt-version) (eq kdab-qt-version 4))
-      (insert "kDebug() << ")
-    (insert "kdDebug() << k_funcinfo "))
-  (insert "<< endl;")
-  (backward-char 8)
+    (progn ; KDE4 version
+      (insert "kDebug() << this << ;")
+      (backward-char 1)
+      )
+    (progn ; KDE3 version
+      (insert "kdDebug() << k_funcinfo "))
+      (insert "<< endl;")
+      (backward-char 8)
+      )
   )
 
 ; finds a string to be used in the header-protection function ( see below )
