@@ -1,11 +1,10 @@
 /***************************************************************************
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2007                                               *
+ *   copyright (C) 2002-2008                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -81,7 +80,7 @@ public:
      *
      * @param type      pointer to the type object
      */
-    void setType(UMLObject *type);
+    void setType(UMLObject* type);
 
     /**
      * Move a parameter one position to the left.
@@ -112,7 +111,7 @@ public:
      *
      * @return a list of the parameters in the operation
      */
-    UMLAttributeList getParmList() {
+    UMLAttributeList getParmList() const {
         return m_List;
     }
 
